@@ -36,7 +36,7 @@ struct DownloadConfig
     unsigned int iGalaxyCDN;
     std::vector<unsigned int> vPlatformPriority;
     std::vector<unsigned int> vLanguagePriority;
-    std::vector<unsigned int> vGalaxyCDNPriority;
+    std::vector<std::string> vGalaxyCDNPriority;
     std::vector<std::string> vTags;
     unsigned int iInclude;
     unsigned int iGalaxyPlatform;
@@ -232,6 +232,7 @@ class Config
 
         // Booleans
         bool bLogin;
+        bool bForceBrowserLogin;
         bool bSaveConfig;
         bool bResetConfig;
 
@@ -256,6 +257,7 @@ class Config
 #endif
         bool bUseFastCheck;
         bool bTrustAPIForExtras;
+        bool bGalaxyListCDNs;
 
         // Cache
         bool bUseCache;
