@@ -547,35 +547,51 @@ std::string galaxyAPI::getPathFromDownlinkUrl(const std::string& downlink_url, c
 {
     std::string path;
     std::string downlink_url_unescaped = (std::string)curl_easy_unescape(curlhandle, downlink_url.c_str(), downlink_url.size(), NULL);
+    size_t filename_start_pos = 0;
 
-    // GOG has changed the url formatting few times between 2 different formats.
-    // Try to get proper file name in both cases.
-    size_t filename_end_pos;
-    if (downlink_url_unescaped.find("?path=") != std::string::npos)
+    // If url ends in "/" then remove it
+    if (downlink_url_unescaped.back() == '/')
+        downlink_url_unescaped.assign(downlink_url_unescaped.begin(), downlink_url_unescaped.end()-1);
+
+    // Assume that filename starts after last "/" in url
+    if (downlink_url_unescaped.find_last_of("/") != std::string::npos)
+        filename_start_pos = downlink_url_unescaped.find_last_of("/") + 1;
+
+    // Url contains "/gamename/"
+    if (downlink_url_unescaped.find("/" + gamename + "/") != std::string::npos)
+        filename_start_pos = downlink_url_unescaped.find("/" + gamename + "/");
+
+    // Assume that filename ends at the end of url
+    size_t filename_end_pos = downlink_url_unescaped.length();
+
+    // Check to see if url has any query strings
+    if (downlink_url_unescaped.find("?") != std::string::npos)
     {
-        size_t token_pos = downlink_url_unescaped.find("&token=");
-        size_t access_token_pos = downlink_url_unescaped.find("&access_token=");
-        if ((token_pos != std::string::npos) && (access_token_pos != std::string::npos))
-        {
-            filename_end_pos = std::min(token_pos, access_token_pos);
-        }
-        else
-        {
-            filename_end_pos = downlink_url_unescaped.find_first_of("&");
-        }
-    }
-    else
+        // Assume that filename ends at first "?"
         filename_end_pos = downlink_url_unescaped.find_first_of("?");
 
-    if (downlink_url_unescaped.find("/" + gamename + "/") != std::string::npos)
-    {
-        path.assign(downlink_url_unescaped.begin()+downlink_url_unescaped.find("/" + gamename + "/"), downlink_url_unescaped.begin()+filename_end_pos);
+        // Check for "?path="
+        if (downlink_url_unescaped.find("?path=") != std::string::npos)
+        {
+            size_t token_pos = downlink_url_unescaped.find("&token=");
+            size_t access_token_pos = downlink_url_unescaped.find("&access_token=");
+            if ((token_pos != std::string::npos) && (access_token_pos != std::string::npos))
+            {
+                filename_end_pos = std::min(token_pos, access_token_pos);
+            }
+            else
+            {
+                if (downlink_url_unescaped.find_first_of("&") != std::string::npos)
+                    filename_end_pos = downlink_url_unescaped.find_first_of("&");
+            }
+        }
     }
-    else
-    {
-        path.assign(downlink_url_unescaped.begin()+downlink_url_unescaped.find_last_of("/")+1, downlink_url_unescaped.begin()+filename_end_pos);
+
+    path.assign(downlink_url_unescaped.begin()+filename_start_pos, downlink_url_unescaped.begin()+filename_end_pos);
+
+    // Make sure that path contains "/gamename/"
+    if (path.find("/" + gamename + "/") == std::string::npos)
         path = "/" + gamename + "/" + path;
-    }
 
     // Workaround for filename issue caused by different (currently unknown) url formatting scheme
     // https://github.com/Sude-/lgogdownloader/issues/126
@@ -590,7 +606,7 @@ std::string galaxyAPI::getPathFromDownlinkUrl(const std::string& downlink_url, c
     return path;
 }
 
-std::vector<std::string> galaxyAPI::cdnUrlTemplatesFromJson(const Json::Value& json, const std::vector<unsigned int>& cdnPriority)
+std::vector<std::string> galaxyAPI::cdnUrlTemplatesFromJson(const Json::Value& json, const std::vector<std::string>& cdnPriority)
 {
     // Handle priority of CDNs
     struct urlPriority
@@ -606,10 +622,9 @@ std::vector<std::string> galaxyAPI::cdnUrlTemplatesFromJson(const Json::Value& j
         std::string endpoint_name = json["urls"][i]["endpoint_name"].asString();
 
         unsigned int score = cdnPriority.size();
-        unsigned int cdn = Util::getOptionValue(endpoint_name, GlobalConstants::GALAXY_CDNS, false);
         for (unsigned int idx = 0; idx < score; ++idx)
         {
-            if (cdn & cdnPriority[idx])
+            if (endpoint_name == cdnPriority[idx])
             {
                 score = idx;
                 break;
@@ -625,36 +640,20 @@ std::vector<std::string> galaxyAPI::cdnUrlTemplatesFromJson(const Json::Value& j
         }
 
         // Build url according to url_format
-        std::string link_base_url = json["urls"][i]["parameters"]["base_url"].asString();
-        std::string link_path = json["urls"][i]["parameters"]["path"].asString();
-        std::string link_token = json["urls"][i]["parameters"]["token"].asString();
-
-        // Add our own template to path
-        link_path += "{LGOGDOWNLOADER_GALAXY_PATH}";
-
         std::string url = json["urls"][i]["url_format"].asString();
+        for (auto cdn_url_template_param : json["urls"][i]["parameters"].getMemberNames())
+        {
+            std::string template_to_replace = "{" + cdn_url_template_param + "}";
+            std::string replacement = json["urls"][i]["parameters"][cdn_url_template_param].asString();
 
-        while(Util::replaceString(url, "{base_url}", link_base_url));
-        while(Util::replaceString(url, "{path}", link_path));
-        while(Util::replaceString(url, "{token}", link_token));
+            // Add our own template to path
+            if (template_to_replace == "{path}")
+            {
+                replacement += "{LGOGDOWNLOADER_GALAXY_PATH}";
+            }
 
-        // Highwinds specific
-        std::string link_hw_l= json["urls"][i]["parameters"]["l"].asString();
-        std::string link_hw_source = json["urls"][i]["parameters"]["source"].asString();
-        std::string link_hw_ttl = json["urls"][i]["parameters"]["ttl"].asString();
-        std::string link_hw_gog_token = json["urls"][i]["parameters"]["gog_token"].asString();
-
-        while(Util::replaceString(url, "{l}", link_hw_l));
-        while(Util::replaceString(url, "{source}", link_hw_source));
-        while(Util::replaceString(url, "{ttl}", link_hw_ttl));
-        while(Util::replaceString(url, "{gog_token}", link_hw_gog_token));
-
-        // Lumen specific
-        std::string dirs = json["urls"][i]["parameters"]["dirs"].asString();
-        std::string expires_at = json["urls"][i]["parameters"]["expires_at"].asString();
-
-        while(Util::replaceString(url, "{dirs}", dirs));
-        while(Util::replaceString(url, "{expires_at}", expires_at));
+            while(Util::replaceString(url, template_to_replace, replacement));
+        }
 
         urlPriority cdnurl;
         cdnurl.url = url;
